==> ansela_0.6-2.tar.gz: ansela-0.6/src/opt/anselA/filters/bw.py <==
# -*- coding: utf-8 -*-
#CPE 1704 TKS
"""
Standard Manupilation modules that are not directly UI based.
"""
from PIL import Image
from PIL import ImageDraw
from PIL import ImageEnhance
from PyQt4 import QtCore as QtCore
from PyQt4 import QtGui as QtGui 
from filters.toolbox import pil2qpixmap
from filters.display import *

def Convert_BW(self, imageToEdit, cSource, UpdateRealImage):
    if  (self.core.lockUpdating == False):
        if (UpdateRealImage == True):
            self.showUpdateLabel(True,  False)
        else:
            self.showUpdateLabel(True,  True)

        im = imageToEdit
        source = im.split()
        R, G, B = 0, 1, 2
        imCMYK=im.convert("CMYK")
        C, M, Y, K = imCMYK.split()
        N =  Image.new('L', im.size, (0))


        if cSource == "R":
            im = source[R].convert("L")
        elif cSource == "G":
            im = source[G].convert("L")
        elif cSource == "B":
            im = source[B].convert("L")
        elif cSource == "C":
            out = Image.merge("RGB", (N, source[G],  source[B]))
            im = out.convert("L")
        elif cSource == "BC":
            out = Image.merge("RGB", (source[B], source[G],  source[B]))
            im = out.convert("L")
        elif cSource == "BM":
            out = Image.merge("RGB", (source[R], source[B],  source[B]))
            im = out.convert("L")
        elif cSource == "M":
            out = Image.merge("RGB", (source[R], N,  source[B]))
            im = out.convert("L")
        elif cSource == "RM":
            out = Image.merge("RGB", (source[R], source[R],  source[B]))
            im = out.convert("L")
        elif cSource == "RY":
            out = Image.merge("RGB", (source[R], source[G],  source[R]))
            im = out.convert("L")
        elif cSource == "Y":
            out = Image.merge("RGB", (source[R], source[G],  N))
            im = out.convert("L")
        elif cSource == "GY":
            out = Image.merge("RGB", (source[R], source[G],  source[G]))
            im = out.convert("L")                
        elif cSource == "GC":
            out = Image.merge("RGB", (source[G], source[G],  source[B]))
            im = out.convert("L")    

        im = im.convert("RGB")


        if (UpdateRealImage == True):
            self.photo.setPixmap(pil2qpixmap(im))
            self.showUpdateLabel(False,  False)
        else:
            self.photo_Thumb.setPixmap(pil2qpixmap(im))
            self.showUpdateLabel(False,  True)

==> ansela_0.7-5.tar.gz: ansela-0.7/src/opt/anselA/filters/bw.py <==
# -*- coding: utf-8 -*-
#CPE 1704 TKS
"""
Standard Manupilation modules that are not directly UI based.
"""
from PIL import Image
from PIL import ImageDraw
from PIL import ImageEnhance
from PyQt4 import QtCore as QtCore
from PyQt4 import QtGui as QtGui 
from filters.toolbox import pil2qpixmap
from filters.display import *

def Convert_BW(self, imageToEdit, cSource, UpdateRealImage):

    if DisplayWait_Enable(self,  UpdateRealImage):

        im = imageToEdit
        source = im.split()
        R, G, B = 0, 1, 2
        imCMYK=im.convert("CMYK")
        C, M, Y, K = imCMYK.split()
        N =  Image.new('L', im.size, (0))

    #"red:0.299; green:0.587; blue:0.114"
        if cSource == "R":
            im = source[R].convert("L")
        elif cSource == "G":
            im = source[G].convert("L")
        elif cSource == "B":
            im = source[B].convert("L")
        elif cSource == "C":
            out = Image.merge("RGB", (N, source[G],  source[B]))
            im = out.convert("L")
        elif cSource == "BC":
            out = Image.merge("RGB", (source[B], source[G],  source[B]))
            im = out.convert("L")
        elif cSource == "BM":
            out = Image.merge("RGB", (source[R], source[B],  source[B]))
            im = out.convert("L")
        elif cSource == "M":
            out = Image.merge("RGB", (source[R], N,  source[B]))
            im = out.convert("L")
        elif cSource == "RM":
            out = Image.merge("RGB", (source[R], source[R],  source[B]))
            im = out.convert("L")
        elif cSource == "RY":
            out = Image.merge("RGB", (source[R], source[G],  source[R]))
            im = out.convert("L")
        elif cSource == "Y":
            out = Image.merge("RGB", (source[R], source[G],  N))
            im = out.convert("L")
        elif cSource == "GY":
            out = Image.merge("RGB", (source[R], source[G],  source[G]))
            im = out.convert("L")                
        elif cSource == "GC":
            out = Image.merge("RGB", (source[G], source[G],  source[B]))
            im = out.convert("L")    

        im = im.convert("RGB")

        DisplayWait_Disable(self,  UpdateRealImage,  im)
